import React, { useState, useEffect, useRef } from "react";
import { FaStar } from "react-icons/fa";
import { motion } from "framer-motion";

type WatchHeroProps = {
  movie: {
    backdrop_path?: string;
    title?: string;
    release_date?: string;
    vote_average?: number;
    genres?: { name: string }[];
    overview?: string; // Adding synopsis (overview)
  };
};

const WatchHero: React.FC<WatchHeroProps> = ({ movie }) => {
  const [isExpanded, setIsExpanded] = useState(false); // State for read more
  const [showReadMore, setShowReadMore] = useState(false); // State to conditionally show "Read More"
  const descriptionRef = useRef<HTMLParagraphElement>(null); // Reference for description element

  const backgroundImage = movie.backdrop_path
    ? `https://image.tmdb.org/t/p/original${movie.backdrop_path}`
    : "/default-backdrop.jpg"; // Fallback image if no backdrop is available

  const title = movie.title || "Unknown Title";
  const releaseYear = movie.release_date
    ? new Date(movie.release_date).getFullYear()
    : "N/A";
  const voteAverage = movie.vote_average ? movie.vote_average.toFixed(1) : "N/A";
  const genres = movie.genres?.length
    ? movie.genres.map((genre) => genre.name).join(", ")
    : "N/A";

  const overview = movie.overview || "No synopsis available."; // Movie description

  const toggleExpanded = () => setIsExpanded(!isExpanded); // Toggle description

  // Effect to check if the description exceeds 1 line
  useEffect(() => {
    const descriptionEl = descriptionRef.current;
    if (descriptionEl) {
      const lineHeight = parseFloat(window.getComputedStyle(descriptionEl).lineHeight);
      const maxHeight = 1 * lineHeight; // Calculate the height for 1 line
      if (descriptionEl.scrollHeight > maxHeight) {
        setShowReadMore(true); // Show "Read More" if content exceeds 1 line
      }
    }
  }, []);

  return (
    <div
      className="relative h-[60vh] md:h-[70vh] w-screen flex flex-col justify-end text-center bg-cover bg-center overflow-hidden"
      style={{ backgroundImage: `url(${backgroundImage})` }}
    >
      {/* Bottom fade overlay */}
      <div className="absolute inset-0 bg-gradient-to-t from-black to-transparent"></div>

      <div className="relative z-10 text-white mb-12 px-4 animate-fadeInUp">
        {/* Movie Title */}
        <h1 className="text-3xl lg:text-5xl font-bold mb-4 animate-slideInUp">
          {title} {releaseYear !== "N/A" && `(${releaseYear})`}
        </h1>

        {/* Rating, Release Date, and Genres */}
        <div className="flex justify-center items-center space-x-4 mb-2 animate-fadeIn">
          <div className="flex items-center">
            <FaStar className="h-5 w-5 text-yellow-400 mr-1" />
            <span>{voteAverage}</span>
          </div>
          <span>•</span>
          <span>{releaseYear}</span>
        </div>

        {/* Genres */}
        <p className="text-sm lg:text-lg animate-slideInUp">
          Genres: {genres}
        </p>

        {/* Movie Description */}
        <div className="mt-4 text-sm lg:text-lg animate-slideInUp">
          {/* Conditionally show short or full description */}
          <motion.p
            ref={descriptionRef}
            className={`${
              isExpanded ? "max-h-full" : "max-h-[1.5em] overflow-hidden"
            } transition-all duration-500 ease-in-out`}
            style={{ lineClamp: !isExpanded ? 1 : "unset" }}
          >
            {overview}
          </motion.p>

          {/* Conditionally render the Read More button only if needed */}
          {showReadMore && (
            <button
              onClick={toggleExpanded}
              className="text-red-500 mt-2 underline hover:text-red-700 transition-colors duration-300"
            >
              {isExpanded ? "Show Less" : "Read More"}
            </button>
          )}
        </div>
      </div>
    </div>
  );
};

export default WatchHero;
